@@ -173,7 +173,7 @@ roc.utils.max.thresholds.idx <- function(thresholds, sp, se) {
 # Define which progress bar to use
 roc.utils.get.progress.bar <- function(name = getOption("pROCProgress")$name, title = "Bootstrap", label = "", width = getOption("pROCProgress")$width, char = getOption("pROCProgress")$char, style = getOption("pROCProgress")$style, ...) {
   if (name == "tk") { # load tcltk if possible
-    if (!require(tcltk)) {
+    if (!requireNamespace("tcltk")) {
       # If tcltk cannot be loaded fall back to default text progress bar
       name <- "text"
       style <- 3
